@@ -53,7 +53,7 @@ $lang = array_merge($lang, array(
 	'SYSTEM_TIMEZONE'            => 'Времева зона (за Гости)',
     'SYSTEM_TIMEZONE_EXPLAIN'         => 'Това е времевата зона за гости и ботове. Регистрираните (логнати) потребители могат да сменят своята времева зона предвид тяхното местоположение в техния контролен панел.',
 	'WARNINGS_EXPIRE'				=> 'Времетраене на предупреждението',
-	'WARNINGS_EXPIRE_EXPLAIN'		=> 'Дните след които предупрежденията ще се премахват автоматично от потребителите.',
+	'WARNINGS_EXPIRE_EXPLAIN'		=> 'Дните след които предупрежденията ще се премахват автоматично. Задайте 0 за безкрайно.',
 ));
 
 // Board Features
@@ -173,7 +173,7 @@ $lang = array_merge($lang, array(
 	'MAX_POST_URLS'					=> 'Максимум връзки на мнение',
 	'MAX_POST_URLS_EXPLAIN'			=> 'Максималния брой връзки в мнение. Задай 0 за неограничен брой.',
 	'MIN_CHAR_LIMIT'				=> 'Минимум знаци при мнение',
-	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'Задава минимален брой знаци за мнение, ако има по-малко от въпросната настройка, потребителя не може да изпрати съобщението.',
+	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'Задава минимален брой знаци за мнение, ако има по-малко от въпросната настройка, потребителя не може да изпрати съобщението. Минимума е 1.',
 	'POSTING'						=> 'Писане',
 	'POSTS_PER_PAGE'				=> 'Мнения на страница',
 	'QUOTE_DEPTH_LIMIT'            => 'Максимална дълбочина при цитиране',
