@@ -324,6 +324,16 @@ $lang = array_merge($lang, array(
 
 	'DATABASE_SERVER_INFO'	=> 'База данни',
 	'DATABASE_SIZE'			=> 'Размер на базата данни',
+	
+// Enviroment configuration checks, mbstring related
+   'ERROR_MBSTRING_FUNC_OVERLOAD'               => 'Функцията overloading е неправилно конфигурирана',
+   'ERROR_MBSTRING_FUNC_OVERLOAD_EXPLAIN'         => '<var>mbstring.func_overload</var> трябва да е зададена на 0 или 4. За да видите как е зададена в момента, посетете <samp>PHP information</samp> страницата.',
+   'ERROR_MBSTRING_ENCODING_TRANSLATION'         => 'Кодировката за прозрачните знаци е неправилно настроена.',
+   'ERROR_MBSTRING_ENCODING_TRANSLATION_EXPLAIN'   => '<var>mbstring.encoding_translation</var> трябва да е 0. За да видите как е зададена в момента, посетете <samp>PHP information</samp> страницата.',
+   'ERROR_MBSTRING_HTTP_INPUT'                  => 'HTTP input character conversion е неправилно настроена.',
+   'ERROR_MBSTRING_HTTP_INPUT_EXPLAIN'            => '<var>mbstring.http_input</var> трябва да е <samp>pass</samp>. За да видите как е зададена в момента, посетете <samp>PHP information</samp> страницата.',
+   'ERROR_MBSTRING_HTTP_OUTPUT'               => 'HTTP output character conversion е неправилно настроена.',
+   'ERROR_MBSTRING_HTTP_OUTPUT_EXPLAIN'         => '<var>mbstring.http_output</var> трябва да е <samp>pass</samp>. За да видите как е зададена в момента, посетете <samp>PHP information</samp> страницата.',
 
 	'FILES_PER_DAY'		=> 'Прикачени файлове на ден',
 	'FORUM_STATS'		=> 'Статистики',
