@@ -40,7 +40,7 @@ if (empty($lang) || !is_array($lang))
 //
 
 $lang = array_merge($lang, array(
-    'TRANSLATION_INFO'  => '<a href="http://papagal.bg">Хостинг и Домейни</a>',
+    'TRANSLATION_INFO'  => '<a href="http://novlaptop.bg">Лаптопи</a>',
     'DIRECTION'         => 'ltr',
     'DATE_FORMAT'       => '|d M Y|',    // 01 Jan 2007 (with Relative days enabled)
     'USER_LANG'         => 'bg',
@@ -165,6 +165,7 @@ $lang = array_merge($lang, array(
     'EMPTY_MESSAGE_SUBJECT'				=> 'Трябва да въведете заглавие.',
 	'ENABLED'                           => 'Включено',
     'ENCLOSURE'                         => 'Ограждане',
+	'ENTER_USERNAME'               => 'Въведете потребителско име',
     'ERR_CHANGING_DIRECTORY'            => 'Не мога да променя директорията',
     'ERR_CONNECTING_SERVER'             => 'Грешка при връзка със сървъра',
     'ERR_JAB_AUTH'                      => 'Не мога да се оторизирам в Jabber сървъра.',
@@ -200,6 +201,7 @@ $lang = array_merge($lang, array(
     'FORUM_RULES_LINK'      => 'Натиснете за да видите правилата',
     'FROM'                  => 'от',
     'FSOCK_DISABLED'        => 'Fsock функциите са изключени, операцията не може да бъде изпълнена.',
+	'FSOCK_TIMEOUT'         => 'Времето за четене е надхвърлено (fsock).',
 
     'FTP_FSOCK_HOST'                => 'FTP host',
     'FTP_FSOCK_HOST_EXPLAIN'        => 'FTP сървър',
@@ -398,6 +400,10 @@ $lang = array_merge($lang, array(
     'NO_TOPICS_TIME_FRAME'        => 'Няма съществуващи теми в това времево пространство.',
     'NO_UNREAD_PM'                => '<strong>0</strong> непрочетени съобщения',
 	'NO_UNREAD_POSTS'         => 'Няма непрочетени мнения',
+	'UNWATCH_FORUM_CONFIRM'      => 'Сигурен ли сте, че вече не искате да следите този форум?',
+   'UNWATCH_FORUM_DETAILED'   => 'Сигурен ли сте, че вече не искате да следите форума “%s”?',
+   'UNWATCH_TOPIC_CONFIRM'      => 'Сигурен ли сте, че вече не искате да следите тази тема?',
+   'UNWATCH_TOPIC_DETAILED'   => 'Сигурен ли сте, че вече не искате да следите темата “%s”?',
     'NO_UPLOAD_FORM_FOUND'        => 'Невалиден файл.',
     'NO_USER'                    => 'Потребителя не съществува.',
     'NO_USERS'                    => 'Потребителите не съществуват.',
@@ -699,6 +705,10 @@ $lang = array_merge($lang, array(
 
     'WARNINGS'            => 'Предупреждения',
     'WARN_USER'            => 'Сложи предупреждение',
+	'WATCH_FORUM_CONFIRM'   => 'Сигурен ли сте, че искате да следите този форум?',
+   'WATCH_FORUM_DETAILED'   => 'Сигурен ли сте, че искате да следите форума “%s”?',
+   'WATCH_TOPIC_CONFIRM'   => 'Сигурен ли сте, че искате да следите тази тема?',
+   'WATCH_TOPIC_DETAILED'   => 'Сигурен ли сте, че искате да следите темата “%s”?',
     'WELCOME_SUBJECT'    => 'Добре дошли в %s форуми',
     'WEBSITE'            => 'Уеб-сайт',
     'WHOIS'                => 'Провери го',
