@@ -138,6 +138,7 @@ $lang = array_merge($lang, array(
 	'CURRENT_IMAGE'				=> 'Аватар',
 	'CURRENT_PASSWORD'			=> 'Парола',
 	'CURRENT_PASSWORD_EXPLAIN'	=> 'При промяна на парола се изисква въвеждането на настоящата.',
+	'CUR_PASSWORD_EMPTY'      => 'Трябва да въведете текущата ви парола.',
 	'CUR_PASSWORD_ERROR'		=> 'Паролата е грешна.',
 	'CUSTOM_DATEFORMAT'			=> 'По ваш избор…',
 
@@ -267,10 +268,12 @@ $lang = array_merge($lang, array(
 	'MOVE_PM_ERROR'					=> 'Грешка при преместването на съобщенията в новата папка, само %1d от %2d съобщения бяха преместени.',
 	'MOVE_TO_FOLDER'				=> 'Премести в папка',
 	'MOVE_UP'						=> 'Премести нагоре',
+	'NEW_EMAIL_CONFIRM_EMPTY'      => 'Не въведохте мейл за потвърждение.',
 
 	'NEW_EMAIL_ERROR'				=> 'Email адреса който сте въвели не съвпада.',
 	'NEW_FOLDER_NAME'				=> 'Ново име на папка',
 	'NEW_PASSWORD'					=> 'Нова парола',
+	'NEW_PASSWORD_CONFIRM_EMPTY'   => 'Трябва да въведете потвърждение на паролата.',
 	'NEW_PASSWORD_ERROR'			=> 'Новата парола която сте въвели не съвпада.',
 	'NOTIFY_METHOD'					=> 'Уведомителен метод',
 	'NOTIFY_METHOD_BOTH'			=> 'и двете',
